@@ -22,14 +22,13 @@
 
 #include "port.h"
 
-#include <QObject>
 #include "debug.h"
+#include <QObject>
 #include <pulse/introspect.h>
 
 namespace PulseAudioQt
 {
-
-class CardPort : public Port
+class KF5PULSEAUDIOQT_EXPORT CardPort : public Port
 {
     Q_OBJECT
     Q_PROPERTY(QVariantMap properties READ properties NOTIFY propertiesChanged)
